###########################################################################
#
# win32.mak -- Windows Makefile for runtime-src\src\recpt
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999-2010  The New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################


# Programs compiled and their install directories
CGIBIN_DIR = $(GSDLHOME)\cgi-bin
CGIBIN_PROGRAMS = library.cgi

# Program: library.cgi
LIBRARY_CGI_CPPFLAGS = \
	-I$(GSDLHOME)\common-src\src\lib \
	-I$(GSDLHOME)\runtime-src\src\colservr \
	-I$(GSDLHOME)\runtime-src\src\protocol \
	-I$(GSDLHOME)\common-src\packages\windows\crypt\crypt

# Objects for library.cgi
LIBRARY_CGI_OBJECTS = \
	action.obj \
	argdb.obj \
	authenaction.obj \
	browseaction.obj \
	browseactiontools.obj \
	browserclass.obj \
	browsetoolsclass.obj \
	cgiargs.obj \
	cgiutils.obj \
	cgiwrapper.obj \
	collectoraction.obj \
	configaction.obj \
	converter.obj \
	datelistbrowserclass.obj \
	depositoraction.obj \
	documentaction.obj \
	dynamicclassifieraction.obj \
	extlinkaction.obj \
	formattools.obj \
	gtiaction.obj \
	highlighttext.obj \
	historydb.obj \
	hlistbrowserclass.obj \
	htmlbrowserclass.obj \
	htmlutils.obj \
	invbrowserclass.obj \
	librarymain.obj \
	maincfg.obj \
	pageaction.obj \
	pagedbrowserclass.obj \
	phindaction.obj \
	phindbrowserclass.obj \
	pingaction.obj \
	queryaction.obj \
	querytools.obj \
	receptionist.obj \
	statusaction.obj \
	string_pool.obj \
	summarise.obj \
	tipaction.obj \
	userdb.obj \
	usersaction.obj \
	vlistbrowserclass.obj \
	wizardaction.obj

LIBRARY_CGI_LDADD = \
	$(GSDLHOME)\runtime-src\src\protocol\gsdlprotocol.lib \
	$(GSDLHOME)\runtime-src\src\colservr\gsdlcolservr.lib \
	$(GSDLHOME)\common-src\src\lib\gsdllib.lib \
	$(GSDLHOME)\common-src\packages\windows\crypt\crypt\crypt.lib


# Option: SQLite support
!IF $(USE_SQLITE)
LIBRARY_CGI_LDADD = $(LIBRARY_CGI_LDADD) $(GSDLHOME)\common-src\packages\sqlite\lib\sqlite3.lib
!ENDIF


COMPILE = cl -nologo -c -EHsc -D__WIN32__ -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE $(LIBRARY_CGI_CPPFLAGS)
LINK = cl -nologo -Fe"$@" 

.SUFFIXES:
.SUFFIXES: .cpp .obj

.cpp.obj:
	$(COMPILE) $<


library.cgi: $(LIBRARY_CGI_OBJECTS) $(LIBRARY_CGI_LDADD)
	$(LINK) $(LIBRARY_CGI_OBJECTS) $(LIBRARY_CGI_LDADD)

all: $(CGIBIN_PROGRAMS)

install: $(CGIBIN_PROGRAMS)
	copy $(CGIBIN_PROGRAMS) $(CGIBIN_DIR)

distclean:
	del *.obj $(CGIBIN_PROGRAMS) win32.mak

clean:
	del *.obj $(CGIBIN_PROGRAMS)
